/* 
   Author: Joel W. Reed (joelreed@yahoo.com).  Copyright 1999.
   This file is distributed  under the Artistic License.
   See the file LICENSE for details.
*/

#include "argparse.h"

const char* argp_program_version = VERSION;
const char* argp_program_bug_address = "joelreed@yahoo.com";
static const char doc[]="nunu is a scriptable neural network, a component of SSAP\n";

static struct argp_option options[] = 
{
	{ "silent", 's', 0, 0, "Supress all error messages"},
	{ "verbose", 'v', 0, 0, "Produce verbose output" },
	{ "first", 'f', "<list>", 0, "A comma separated list of the first layer's input keys. Also used to determine layer's node count." },
	{ "last", 'l', "<list>", 0, "A comma separated list of the last layer's output keys. Also used to determine the layer's node count." },
	{ "middle", 'm', "<list>", 0, "A comma separated list of node counts for the hidden layers 2->(N-1). No spaces allowed!" },
	{ "pattern", 'p', "<pattern>", 0, "The pattern input file name, use \"-\" for stdin (default=\"-\"). This file consists of a sequencies of key-value pairs delimited by newlines." },
	{ "target", 't', "<target>", 0, "The desired target for the given pattern. This should be one of the entries for the last layer of nodes. Currently, we assume desired target strength is 1, all others 0." },
	{ "network", 'n', "<network>", 0, "The filename of a saved network." },
	{ "output", 'o',  "<filename>", 0, "The output file, use \"-\" for stdout (default is <network> when -n specified, else the default is standard output. )" },
	{ 0, 0, 0, doc },
};

static error_t parse_opt (int key, char* arg, struct argp_state* state)
{
	string t; char* comma;
	arguments* args = (arguments*)state->input;

	switch (key)
	{
	case 's': args->silent = 1; break;
	case 'v': args->verbose = 1; break;
	case 'o': args->out_fname = arg; break;
	case 'n':
		args->network_fname = arg; 
		if (args->out_fname==0) args->out_fname = arg;
		break;
	case 'p': args->pattern_fname = arg; break;
	case 't': args->target = arg; break;
	case 'm': 
		// now parse up create_list if need be
		while ((arg!= 0)&&(*arg!='\0'))
		{
			char* comma = strchr(arg, ',');
			if (comma) t = std::string(arg, comma);
			else t = std::string(arg);
			
			args->nn_dims.push_back(atoi(t.c_str()));
			arg = (comma)? comma+1 : 0;
		}
		break;
	case 'f':	
		while ((arg != 0)&&(*arg!='\0'))
		{
			char* comma = strchr(arg, ',');
			if (comma) t = std::string(arg, comma);
			else t = std::string(arg);
			
			args->l1_tags.push_back(t);
			arg = (comma)? comma+1 : 0;
		}		
		break;
	case 'l':
		while ((arg != 0)&&(*arg!='\0'))
		{
			char* comma = strchr(arg, ',');
			if (comma) t = std::string(arg, comma);
			else t = std::string(arg);
			
			args->ln_tags.push_back(t);
			arg = (comma)? comma+1 : 0;
		}		
		break;
	default:
		return ARGP_ERR_UNKNOWN;
	};

	return 0;
}

struct argp parser = { options, parse_opt, 0, doc };

